Learn R Programming

ridgregextra (version 0.1.1)

vif_k: Ridge regression tables in the range of given lower and upper bounds of k values

Description

Ridge regression tables in the range of given lower and upper bounds of k values

Usage

vif_k(x, y, a, b)

Value

A list of lists

Arguments

x

Explanatory variables (Dataframe, matrix)

y

Dependent variables (Dataframe, vector)

a

Lower bound of k

b

Upper bound of k

Examples

Run this code
library("mctest")
x <- Hald[,-1]
y <- Hald[,1]
vif_k(x,y,a=0,b=1)

library(isdals)
data(bodyfat)
x <- bodyfat[,-1]
y <- bodyfat[,1]
vif_k(x,y,a=0,b=1)

Run the code above in your browser using DataLab